Installation
============
The most recent release can be installed from
`PyPI <https://pypi.org/project/bioregistry>`_ with:

.. code-block:: shell

    $ pip install bioregistry

The most recent code and data can be installed directly from GitHub with:

.. code-block:: shell

    $ pip install git+https://github.com/biopragmatics/bioregistry.git

To install in development mode, use the following:

.. code-block:: shell

    $ git clone git+https://github.com/biopragmatics/bioregistry.git
    $ cd bioregistry
    $ pip install -e .
